<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\SiteImage;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\Whatsapp;
use Illuminate\Support\Str;

class SiteSettingController extends Controller
{
    
    public function dashboard()
    {
        $site_images = SiteImage::first(); // Assuming SiteImage is your model

        return view('admin.dashboard', compact('site_images'));
    }
    
    
    public function getMenu()
    {
        $categories = Category::all();
        $data = compact('categories');
        return view('admin.main_menu.index')->with($data);
    }

    public function updateCategoryStatus(Request $request)
    {
        // Validate the request data
        $request->validate([
            'category_id' => 'required|exists:categories,id',
        ]);

        // Get the category
        $category = Category::findOrFail($request->category_id);

        // Get the count of enabled categories
        $enabledCategoriesCount = Category::where('status', true)->count();

        // Check if the requested status is to enable the category
        if ($request->status) {
            // Check if the number of enabled categories is less than or equal to 4
            if ($enabledCategoriesCount < 4) {
                // Update the category status
                $category->update(['status' => 1]);

                // Return success response
                return response()->json(['success' => true]);
            } else {
                // Return error response if more than 4 categories are enabled
                return response()->json(['success' => false, 'message' => 'You can only enable up to 4 categories.']);
            }
        } else {
            // Update the category status if the request is to disable the category
            $category->update(['status' => 0]);

            // Return success response
            return response()->json(['success' => true]);
        }
    }

    public function getSiteImages()
    {
        $site_images = SiteImage::first();
        return view('admin.site_images.index', compact('site_images'));
    }

    public function updateSiteImages(Request $request)
    {
        // Validate the incoming request data
        $request->validate([
            'logo' => 'image|max:2048', // Maximum file size of 2048 KB (2 MB)
            'site_icon' => 'image|max:2048', // Maximum file size of 2048 KB (2 MB)
        ], [
            'logo.max' => 'The logo may not be greater than 2 MB.',
            'site_icon.max' => 'The site icon may not be greater than 2 MB.',
        ]);
    
        // Get the existing site images record or create one if it doesn't exist
        $siteImages = SiteImage::firstOrNew();
    
        // Update logo if provided
        if ($request->hasFile('logo')) {
            $logoFileName = 'logo' . '_' . now()->format('YmdHis') . '.' . $request->file('logo')->getClientOriginalExtension();
            $request->file('logo')->move(public_path('uploads/logo'), $logoFileName);
    
            // Delete the old logo file if it exists
            if ($siteImages->logo) {
                unlink(public_path('uploads/logo/' . $siteImages->logo));
            }
    
            $siteImages->logo = $logoFileName;
        }
    
        // Update site icon if provided
        if ($request->hasFile('site_icon')) {
            $siteIconFileName = 'site_icon' . '_' . now()->format('YmdHis') . '.' . $request->file('site_icon')->getClientOriginalExtension();
            $request->file('site_icon')->move(public_path('uploads/site_icon'), $siteIconFileName);
    
            // Delete the old site icon file if it exists
            if ($siteImages->site_icon) {
                unlink(public_path('uploads/site_icon/' . $siteImages->site_icon));
            }
    
            $siteImages->site_icon = $siteIconFileName;
        }
    
        // Save the changes
        $siteImages->save();
    
        // Redirect back with success message
        return redirect()->back()->with('success', 'Site images updated successfully.');
    }
    
        public function whatsappIndex()
    {
        $whatsapp_configs = Whatsapp::all();
        $data = compact('whatsapp_configs');
        return view('admin.whatsapp.index')->with($data);
    }

    public function whatsappCreate()
    {
        return view('admin.whatsapp.manage_whatsapp', ['id' => null]);
    }




    /**
     * Store a newly created resource in storage.
     */
    public function whatsappStore(Request $request)
    {
        // Validate request data
        $validatedData = $request->validate([
            'phone_number' => 'required|string|regex:/^\+[1-9]\d{1,14}$/',
            'message' => 'required',
        ], [
            'phone_number.required' => 'Phone number is required.',
            'phone_number.regex' => 'Please enter a valid phone number in international format (e.g., +1234567890).',
            'message.required' => 'Message is required.',
        ]);

        // Create a new WhatsApp record with provided data
        $whatsapp = Whatsapp::create([
            'phone_number' => $validatedData['phone_number'],
            'message' => $validatedData['message'],
        ]);

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp added successfully.');
    }


    /**
     * Display the specified resource.
     */
    public function whatsappShow(string $id)
    {
        $whatsapp = Whatsapp::findOrFail($id);
        return view('admin.whatsapp.manage_whatsapp', compact('whatsapp'));
    }
    public function viewWhatsapp(string $id)
    {
        $whatsapp = whatsapp::findOrFail($id);
        return view('admin.whatsapp.view', ['whatsapp' => $whatsapp,]);

    }




    public function whatsappUpdate(Request $request, $id)
    {
        // Validate request data
        $validatedData = $request->validate([
            'phone_number' => 'required|string|regex:/^\+[1-9]\d{1,14}$/',
            'message' => 'required',
        ], [
            'phone_number.required' => 'Phone number is required.',
            'phone_number.regex' => 'Please enter a valid phone number in international format (e.g., +1234567890).',
            'message.required' => 'Message is required.',
        ]);

        // Find the WhatsApp record by ID
        $whatsapp = Whatsapp::findOrFail($id);

        // Update the WhatsApp record with provided data
        $whatsapp->update([
            'phone_number' => $validatedData['phone_number'],
            'message' => $validatedData['message'],
        ]);

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp updated successfully.');
    }



    public function whatsappDelete($id)
    {
        // Find the WhatsApp record by ID
        $whatsapp = Whatsapp::findOrFail($id);

        // Delete the WhatsApp record
        $whatsapp->delete();

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp deleted successfully.');
    }
    
}
