<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Whatsapp;
use Illuminate\Http\Request;

class WhatsappController extends Controller
{
    public function index()
    {
        $whatsapps = Category::all();
        $data = compact('whatsapps');
        return view('admin.whatsapp.index')->with($data);
    }

    public function create()
    {
        return view('admin.whatsapp.manage_whatsapp', ['id' => null]);
    }




    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate request data
        $validatedData = $request->validate([
            'phone_number' => 'required|string|regex:/^\+[1-9]\d{1,14}$/',
            'message' => 'required',
        ], [
            'phone_number.required' => 'Phone number is required.',
            'phone_number.regex' => 'Please enter a valid phone number in international format (e.g., +1234567890).',
            'message.required' => 'Message is required.',
        ]);

        // Create a new WhatsApp record with provided data
        $whatsapp = Whatsapp::create([
            'phone_number' => $validatedData['phone_number'],
            'message' => $validatedData['message'],
        ]);

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp added successfully.');
    }


    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $whatsapp = whatsapp::findOrFail($id);
        return view('admin.whatsapp.manage_whatsapp', compact('whatsapp'));
    }
    public function showModel(string $id)
    {
        $whatsapp = whatsapp::findOrFail($id);
        return response()->json($whatsapp);

    }




    public function update(Request $request, $id)
    {
        // Validate request data
        $validatedData = $request->validate([
            'phone_number' => 'required|string|regex:/^\+[1-9]\d{1,14}$/',
            'message' => 'required',
        ], [
            'phone_number.required' => 'Phone number is required.',
            'phone_number.regex' => 'Please enter a valid phone number in international format (e.g., +1234567890).',
            'message.required' => 'Message is required.',
        ]);

        // Find the WhatsApp record by ID
        $whatsapp = Whatsapp::findOrFail($id);

        // Update the WhatsApp record with provided data
        $whatsapp->update([
            'phone_number' => $validatedData['phone_number'],
            'message' => $validatedData['message'],
        ]);

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp updated successfully.');
    }



    public function delete($id)
    {
        // Find the WhatsApp record by ID
        $whatsapp = Whatsapp::findOrFail($id);

        // Delete the WhatsApp record
        $whatsapp->delete();

        // Redirect back with success message
        return redirect()->route('whatsapp')->with('success', 'WhatsApp deleted successfully.');
    }


}
