<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;
use App\Models\SiteImage;
use App\Models\SubCategory;
use App\Models\Whatsapp;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class FrontendController extends Controller
{
    public function home()
    {
        $site_images = SiteImage::first();
        $twoNewProducts = DB::table('products')
            ->orderBy('created_at', 'desc')
            ->limit(2)
            ->get();
        $newArrivals = DB::table('products')
            ->orderBy('created_at', 'desc')
            ->limit(6)
            ->get();
        $sliderProduct = DB::table('products')
            ->inRandomOrder()
            ->limit(3)
            ->get();
        $popularCategories = Category::whereHas('products2')->with(['subCategory' => function ($query) {
            $query->whereHas('products');
        }])->orderBy('created_at', 'desc')->get();
        $categories = Category::whereHas('products2')->with(['subCategory' => function ($query) {
            $query->whereHas('products');
        }])->get();
        $ImageTabcategories = Category::whereHas('products2')
        ->with(['subCategory' => function ($query) {
            $query->whereHas('products')
                  ->with(['products' => function ($query) {
                      $query->take(10);
                  }]);
        }])
        ->take(5)
        ->get();
        $premiumCategories = Category::whereHas('subCategory.products')->with(['subCategory' => function ($query) {
            $query->has('products'); // Ensures subcategories have at least one product
        }])->get();

        $Tabcategories = Category::whereHas('products2')
        ->with(['subCategory' => function ($query) {
            $query->whereHas('products')
                  ->with(['products' => function ($query) {
                      $query->take(10);
                  }]);
        }])
        ->take(5)
        ->get();
        return view("frontend.pages.index", [
            'site_images' => $site_images,
            'twoNewProducts' => $twoNewProducts,
            'popularCategories' => $popularCategories,
            'categories' => $categories,
            'ImageTabcategories' => $ImageTabcategories,
            'premiumCategories' => $premiumCategories,
            'Tabcategories' => $Tabcategories,
            'sliderProduct' => $sliderProduct,
            'newArrivals' => $newArrivals,
        ]);
    }
    public function getSubCategories($categoryId)
    {
        $category = Category::with('subCategory')->find($categoryId);
        if (!$category) {
            return response()->json(['message' => 'Category not found'], 404);
        }
        return response()->json(['subCategories' => $category->subCategory]);
    }

    public function about()
    {
        $categories = Category::whereHas('products2')->with(['subCategory' => function ($query) {
            $query->whereHas('products');
        }])->get();
        $site_images = SiteImage::first();
        return view('frontend.pages.about', ['site_images' => $site_images , 'categories' => $categories]);
    }
    public function contact()
    {
        $site_images = SiteImage::first();
        $categories = Category::whereHas('products2')->with(['subCategory' => function ($query) {
            $query->whereHas('products');
        }])->get();
        return view('frontend.pages.contact-us', ['site_images' => $site_images, 'categories' => $categories]);
    }
    public function products()
    {
        $products = Product::orderBy('created_at', 'desc')->paginate(12);
        $categories = Category::has('products2')->inRandomOrder()->limit(6)->get();
        return view('frontend.pages.products', ['products' => $products, 'categories' => $categories]);
    }
    public function fetchProductsByCategory(Request $request)
    {
        try {
            $categoryId = $request->category_id;
            $products = Product::whereHas('categories', function ($query) use ($categoryId) {
                // Specify the table name before the 'id'
                $query->where('categories.id', $categoryId);
            })->get();

            return response()->json(['products' => $products]);
        } catch (\Exception $e) {
            // Log the error message
            Log::error('Failed to fetch products by category', ['error' => $e->getMessage()]);
            return response()->json(['message' => 'Error occurred while fetching products'], 500);
        }
    }
    public function productDetails(Request $request, $slug)
    {
        $categories = Category::where('status', 1)->get();
        $product = Product::where('slug', $slug)->firstOrFail();
        $categoryId = $product->category_id;
        $subCategoryId = $product->sub_category_id;
        $relatedProducts = Product::where('category_id', $categoryId)
            ->inRandomOrder()
            ->take(6)
            ->get();
        $whatsappTemplates = Whatsapp::all();
        $site_images = SiteImage::first();
        return view('frontend.pages.product-details', [
            'product' => $product,
            'site_images' => $site_images,
            'relatedProducts' => $relatedProducts,
            'categories' => $categories,
            'whatsappTemplates' => $whatsappTemplates
        ]);
    }
    // In your ProductController
    public function searchProducts(Request $request)
    {
        $query = $request->input('query');
        $products = Product::where('product_name', 'like', '%' . $query . '%')->get();

        return response()->json(['products' => $products]);
    }

    // search start
    public function search(Request $request)
    {
        $categories = Category::where('status', 1)->get();

        $searchQuery = $request->input('query');

        $products = Product::where('product_name', 'like', '%' . $searchQuery . '%')
            ->orWhere('alt_tag', 'like', '%' . $searchQuery . '%')
            ->paginate(9);
        $whatsappTemplates = Whatsapp::all();
        $site_images = SiteImage::first();
        return view('frontend.pages.search_results', compact('products', 'searchQuery', 'whatsappTemplates', 'site_images', 'categories'));
    }
    public function searchSuggest(Request $request)
    {
        $searchQuery = $request->input('query');

        $products = Product::where('product_name', 'like', '%' . $searchQuery . '%')
            ->orWhere('alt_tag', 'like', '%' . $searchQuery . '%')
            ->limit(10)
            ->get();
        $site_images = SiteImage::first();
        return response()->json($products);
    }
    // search end
    public function subcategoryDetail(Request $request, $slug)
    {
        $categories = Category::whereHas('products2')->with(['subCategory' => function ($query) {
            $query->whereHas('products');
        }])->get();
        $subcategory = SubCategory::where('slug', $slug)->firstOrFail();
        $products = $subcategory->products()->paginate(10);
        $category = $subcategory->category;

        $whatsappTemplates = Whatsapp::all();
        $site_images = SiteImage::first();
        return view('frontend.pages.subcategory-products', [
            'subcategory' => $subcategory,
            'category' => $category,
            'site_images' => $site_images,
            'products' => $products,
            'categories' => $categories,
            'whatsappTemplates' => $whatsappTemplates
        ]);
    }


    public function frontendCategory($categorySlug)
    {
        $category = Category::where('slug', $categorySlug)->firstOrFail();
        $subcategories = $category->subCategory()->whereHas('products')->paginate(10); // Adjust the number per page as needed

        // $subcategories = $category->subCategory()->whereHas('products')->get(); // Make sure the relationship name is 'subCategories'
        $categories = Category::has('products2')->inRandomOrder()->limit(6)->get();
        $site_images = SiteImage::first();

        return view('frontend.pages.category', [
            'category' => $category,
            'subcategories' => $subcategories,
            'categories' => $categories,
            'site_images' => $site_images,
        ]);
    }
    public function fetchByCategory(Request $request)
    {
        try {
            $categoryId = $request->category_id;
            if (!$categoryId) {
                return response()->json(['message' => 'Category ID is required'], 400);
            }

            $subcategories = SubCategory::where('ctg_id', $categoryId)->with('products')->get();

            return response()->json(['subcategories' => $subcategories]);
        } catch (\Exception $e) {
            // Log the exception
            Log::error('Failed to fetch subcategories: ' . $e->getMessage());
            return response()->json(['message' => 'Server error occurred'], 500);
        }
    }

}
