@extends('admin.master')

@section('admin-home-section')
    <div class="container-fluid pt-4 px-4">
        <div class="row g-4">
            <h2> Category</h2>
            <div class="col-sm-12 col-xl-12">
                <div class="bg-light rounded h-100 p-4">
                    <h6 class="mb-4">{{ isset($category) ? 'Edit' : 'Add' }} Category</h6>

                    @error('error')
                        {{ $message }}
                    @enderror
                    <form method="POST" enctype="multipart/form-data"
                        action="{{ isset($category) ? route('category.update', ['id' => $category->id]) : route('category.store') }}">
                        @csrf
                        @if (isset($category))
                            @method('PATCH')
                        @endif
                        <div class="row mb-3">
                            <div class="col">
                                <label for="ctg_name" class="form-label">Category Name</label>
                                <input type="text" class="form-control @error('ctg_name') is-invalid @enderror"
                                    id="ctg_name" name="ctg_name"
                                    value="{{ isset($category) ? $category->ctg_name : '' }}">
                                @error('ctg_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                <label for="slug" class="form-label">Slug</label>
                                <input type="text" class="form-control @error('slug') is-invalid @enderror"
                                    id="slug" name="slug" value="{{ isset($category) ? $category->slug : '' }}">
                                @error('slug')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                <label for="alt_tag" class="form-label">Meta keywords</label>
                                <input type="text" class="form-control p-0 bg-white" id="alt_tag" name="alt_tag"
                                    value="{{ isset($category)? implode(', ',collect(json_decode($category->alt_tag))->pluck('value')->toArray()): '' }}">
                            </div>

                            <div class="col">
                                <label for="meta_title" class="form-label">Meta Title</label>
                                <input type="text" class="form-control @error('meta_title') is-invalid @enderror"
                                    id="meta_title" name="meta_title"
                                    value="{{ isset($category) ? $category->meta_title : '' }}">
                                @error('meta_title')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">

                            <div class="col">
                                <label for="meta_description" class="form-label">Meta Description</label>
                                <textarea class="form-control @error('meta_description') is-invalid @enderror" id="meta_description"
                                    name="meta_description">{{ isset($category) ? $category->meta_description : '' }}</textarea>
                                @error('meta_description')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                @if (isset($category))
                                    <label for="ctg_banner" class="form-label">Current Banner Image</label>
                                    <br> <img class="banner-style mb-2" src="{{ asset('uploads/category/banner/' . $category->ctg_banner) }}"
                                        alt="Category Banner" style="max-width: 200px; max-height: 200px;">
                                    <br> <span>Update For New</span>
                                @endif
                                <label for="ctg_banner" class="form-label">Banner Image</label>
                                <input type="file" class="form-control @error('ctg_banner') is-invalid @enderror"
                                    id="ctg_banner" name="ctg_banner">
                                    <small id="helpId" class="text-secondary">The banner image dimensions must be at least 1920x745 pixels*</small>
                                    @error('ctg_banner')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col">
                                    @if (isset($category))
                                    <label for="ctg_main_img" class="form-label">Current Main Image</label>
                                    <br> <img class="banner-style mb-2" src="{{ asset('uploads/category/main/' . $category->ctg_main_img) }}"
                                    alt="Category main img" style="max-width: 200px; max-height: 200px;">
                                    <br> <span>Update For New</span>
                                    @endif
                                    <label for="ctg_main_img" class="form-label">Main Image</label>
                                    <input type="file" class="form-control @error('ctg_main_img') is-invalid @enderror"
                                    id="ctg_main_img" name="ctg_main_img">
                                    <small id="helpId" class="text-secondary">The main image dimensions must be at least 200x176 pixels*</small>
                                @error('ctg_main_img')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <button type="submit" class="btn btn-success mt-4">{!! isset($category) ? '<i class="fa fa-save"></i>  Update' : '<i class="fa fa-plus"></i> Add' !!}</button>
                        <a class="btn btn-danger ms-md-3 mt-4" onclick="location.href='{{ route('category') }}'"><i
                                class="fa fa-arrow-left"></i> Back</a>
                    </form>

                </div>
            </div>
        </div>
    </div>
@endsection
@push('style')
    <style>
        .banner-style {
            aspect-ratio: 16 / 9;
            width: 300px;
            object-fit: cover;
            object-position: center right;
        }
    </style>
@endpush
