@extends('admin.master')

@section('admin-home-section')
    <div class="container-fluid pt-4 px-4">
        <div class="row g-4">
            <h2> Product</h2>
            <div class="col-sm-12 col-xl-12">
                <div class="bg-light rounded h-100 p-4">
                    <h6 class="mb-4">Add Product</h6>

                    @error('error')
                        {{ $message }}
                    @enderror
                    <form method="POST" enctype="multipart/form-data" action="{{ route('products.store') }}">
                        @csrf

                        <div class="row mb-3">
                            <div class="row mb-3 after-add-more">
                                <div class="col">
                                    <label for="category_id" class="form-label">Select Category</label>
                                    <select class="form-control bg-white" id="category_id" name="category_id[]">
                                        <option value="" disabled selected>Select Category</option>
                                        @foreach ($categories as $category)
                                            <option value="{{ $category->id }}">{{ $category->ctg_name }}</option>
                                        @endforeach
                                    </select>
                                    @error('category_id')
                                        <div class="text-danger">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col" id="subcategory-dropdown">
                                    <label for="sub_category_id" class="form-label">Select Sub Category</label>
                                    <div class="input-group mb-3 bg-white rounded">
                                        <button class="btn btn-outline-secondary w-100 dropdown-toggle"
                                            data-bs-auto-close="outside" type="button" data-bs-toggle="dropdown"
                                            aria-expanded="false">Select Sub Category</button>
                                        <ul class="dropdown-menu w-100 p-2">
                                            <!-- Options will be populated dynamically via JavaScript -->
                                        </ul>
                                    </div>
                                    @error('sub_category_id')
                                        <div class="text-danger">{{ $message }}</div>
                                    @enderror
                                </div>

                                <div class="col change d-flex justify-content-center align-items-center">
                                    <button type="button" class="btn btn-success btn-border add-more"><i
                                            class="fas fa-plus"></i> Add More</button>
                                </div>
                            </div>
                        </div>

                        <div class="row mb-3">
                            <div class="col">
                                <label for="product_name" class="form-label">Product Name</label>
                                <input type="text" class="form-control @error('product_name') is-invalid @enderror"
                                    id="product_name" name="product_name">
                                @error('product_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                <label for="short_desc" class="form-label">Short Description</label>
                                <textarea class="form-control @error('short_desc') is-invalid @enderror" id="short_desc" name="short_desc"></textarea>
                                @error('short_desc')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                <label for="product_desc" class="form-label">Product Description</label>
                                <textarea class="form-control  @error('product_desc') is-invalid @enderror" id="editor" name="product_desc"></textarea>
                                @error('product_desc')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                        </div>

                        <div class="row mb-3">
                            <div class="col">
                                <label for="slug" class="form-label">Slug</label>
                                <input type="text" class="form-control @error('slug') is-invalid @enderror"
                                    id="slug" name="slug" value="">
                                @error('slug')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                <label for="meta_title" class="form-label">Meta Title</label>
                                <input type="text" class="form-control @error('meta_title') is-invalid @enderror"
                                    id="meta_title" name="meta_title" value="">
                                @error('meta_title')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="row mb-3">
                            
                            <div class="col">
                                <label for="meta_description" class="form-label">Meta Description</label>
                                <textarea class="form-control @error('meta_description') is-invalid @enderror" id="meta_description"
                                    name="meta_description"></textarea>
                                @error('meta_description')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                <label for="alt_tag" class="form-label">Meta keywords</label>
                                <input type="text" class="form-control" id="alt_tag" name="alt_tag">
                            </div>
                        </div>

                        <div class="row mb-3">
                            <div class="col">
                                <label for="product_main_img" class="form-label">Image</label>
                                <input type="file" class="form-control @error('product_main_img') is-invalid @enderror"
                                    id="product_main_img" name="product_main_img">
                                @error('product_main_img')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                <label for="product_multi_img" class="form-label">Choose Multi Images</label>
                                <input type="file"
                                    class="form-control @error('product_multi_img.*') is-invalid @enderror"
                                    id="product_multi_img" name="product_multi_img[]" multiple>
                                @error('product_multi_img.*')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" id="popular" name="popular"
                                        value="1">
                                    <label class="form-check-label" for="popular">
                                        Mark as Popular
                                    </label>
                                    @error('popular')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <button type="submit" class="btn btn-success">Add</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
@endsection
@push('head')
    <script src="https://cdn.ckeditor.com/ckeditor5/36.0.0/classic/ckeditor.js"></script>
@endpush
@push('scripts')
    <script>
        ClassicEditor
            .create(document.querySelector('#editor'))
            .catch(error => {
                console.error(error);
            });

        ClassicEditor
            .create(document.querySelector('#short_desc'))
            .catch(error => {
                console.error(error);
            });
    </script>

    <script>
        $(document).ready(function() {
            // Function to generate subcategory options with checkboxes
            function generateSubcategoryOptions(subcategories, selectedSubcategories = []) {
                var options = 
                    '<button type="button" class="btn btn-sm btn-primary mt-2 me-2 mb-2" id="select-all-subcategory">Select All</button>' +
                    '<button type="button" class="btn btn-sm btn-secondary mt-2 mb-2" id="unselect-all-subcategory">Unselect All</button>';
                
                $.each(subcategories, function(key, value) {
                    var isChecked = selectedSubcategories.includes(key.toString()) ? 'checked' : '';
                    options += '<li>' +
                        '<input class="form-check-input" type="checkbox" value="' + key +
                        '" id="sub_category_' + key + '" name="sub_category_id[]" ' + isChecked + '>' +
                        '<label class="form-check-label ms-2" for="sub_category_' + key + '">' + value +
                        '</label>' +
                        '</li>';
                });
                return options;
            }

            // Function to disable already selected categories in the dropdowns
            function disableSelectedCategories() {
                $('select[name^="category_id"]').each(function() {
                    var selectedCategoryIds = [];
                    $(this).closest('.after-add-more').siblings('.after-add-more').find(
                        'select[name^="category_id"]').each(function() {
                        var categoryId = $(this).val();
                        if (categoryId) {
                            selectedCategoryIds.push(categoryId);
                        }
                    });

                    $(this).find('option').each(function() {
                        if ($.inArray($(this).val(), selectedCategoryIds) !== -1) {
                            $(this).prop('disabled', true);
                        } else {
                            $(this).prop('disabled', false);
                        }
                    });
                });
            }

            // Event delegation for category dropdown change
            $(document).on('change', 'select[name^="category_id"]', function() {
                var categoryId = $(this).val();
                var subCategoryDropdown = $(this).closest('.row').find(
                    '#subcategory-dropdown ul.dropdown-menu');

                if (categoryId) {
                    $.ajax({
                        type: "GET",
                        url: "{{ route('getSubcategories') }}",
                        data: {
                            category_id: categoryId
                        },
                        success: function(subcategories) {
                            var options = generateSubcategoryOptions(subcategories);
                            subCategoryDropdown.html(options);

                            // Disable already selected categories
                            disableSelectedCategories();
                        }
                    });
                } else {
                    subCategoryDropdown.empty();
                }
            });

            // Add more button functionality
            $(document).on("click", ".add-more", function() {
                var html = $(".after-add-more").first().clone();

                // Clear input values
                $(html).find("input, select").val("");

                // Clear subcategory dropdown
                var subCategoryDropdown = $(html).find("#subcategory-dropdown ul.dropdown-menu");
                subCategoryDropdown.empty();

                // Update input names with unique indices for category and subcategory
                var index = $(".after-add-more").length;
                $(html).find("[name='category_id[]']").attr("name", "category_id[" + index + "][]");
                $(html).find("[name='sub_category_id[]']").attr("name", "sub_category_id[" + index + "][]");

                $(html).find(".change").html(
                    "<span><a class='btn btn-success btn-border add-more'><i class='fas fa-plus'></i> Add More</a></span><span style='margin-left: 25px;'><a class='btn btn-danger btn-border remove'><i class='fas fa-minus'></i> Remove</a></span>"
                );
                $(".after-add-more").last().after(html);

                // Disable already selected categories in the newly added row
                disableSelectedCategories();
            });

            // Remove button functionality
            $(document).on("click", ".remove", function() {
                var parentContainer = $(this).parents(".after-add-more");
                parentContainer.remove();

                // Disable already selected categories after removing a row
                disableSelectedCategories();
            });

            // Select All and Unselect All functionality for subcategories
            $(document).on('click', '#select-all-subcategory', function() {
                $(this).closest('.dropdown-menu').find('input[type="checkbox"]').prop('checked', true);
            });

            $(document).on('click', '#unselect-all-subcategory', function() {
                $(this).closest('.dropdown-menu').find('input[type="checkbox"]').prop('checked', false);
            });
        });
    </script>
@endpush
