@extends('admin.master')

@section('admin-home-section')
    <div class="container-fluid pt-4 px-4">
        <div class="row g-4">
            <h2>Products</h2>
            <div class="col-12">
                @if (session('success'))
                    <div class="alert alert-success">{{ session('success') }}</div>
                @endif
                <div id="alertContainer"></div>
                <button class="btn btn-dark mb-3" onclick="location.href = '{{ route('product.create') }}'"><i
                        class="fa fa-plus"></i> Add New</button>
                <div class="bg-light rounded h-100 p-4">
                    <div class="table-responsive">
                        <table id="productTable" class="table table-striped table-bordered" style="width:100%">
                            <thead>
                                <tr>
                                    <th scope="col">#</th>
                                    <th scope="col">PID</th>
                                    <th scope="col">Name</th>
                                    <th scope="col">Banner</th>
                                    <th scope="col">Slug</th>
                                    <th scope="col">Populer</th>
                                    <th scope="col">Action</th>
                                </tr>
                            </thead>
                            <tbody>
                                @php
                                    $count = 1;
                                @endphp
                                @foreach ($products as $product)
                                    <tr>
                                        <td>{{ $count++ }}</td>
                                        <td>{{ $product->product_id }}</td>
                                        <td>{{ $product->product_name }}</td>
                                        <td><img style="object-fit: contain;" src="{{ asset('uploads/product/main/' . $product->product_main_img) }}"
                                                alt="{{ $product->product_name }}" width="200px" height="80px"></td>
                                        <td>{{ $product->slug }}</td>
                                        <td>
                                            <div class="form-check form-switch">
                                                <input class="form-check-input toggle-popularity" type="checkbox"
                                                    data-popular-id="{{ $product->id }}"
                                                    {{ isset($product) && $product->popular ? 'checked' : '' }}>
                                                <label class="form-check-label" for="flexSwitchCheckChecked">Checked if
                                                    Popular</label>
                                            </div>
                                        </td>
                                        <td>
                                            <div class="btn-group" role="group" aria-label="product Actions">
                                                <button class="btn btn-warning me-2 "
                                                onclick="location.href = '{{ route('product.view', [$product->id]) }}'">
                                                    <i class="fa fa-eye"></i>
                                                </button>
                                                <button class="btn btn-primary me-2"
                                                    onclick="location.href = '{{ route('product.edit', [$product->id]) }}'"><i
                                                        class="fa fa-pen"></i></button>
                                                <form action="{{ route('product.delete', [$product->id]) }}"
                                                    method="post">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button class="btn btn-danger"><i class="fa fa-trash"></i></button>
                                                </form>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
    <script src="https://cdn.datatables.net/1.10.24/js/jquery.dataTables.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#productTable').DataTable({
                "autoWidth": true // Enable auto-width
            });

         


            // product status
            $('.toggle-popularity').change(function() {
                var isChecked = $(this).prop('checked');
                var productId = $(this).data('popular-id');

                // Make AJAX request to update product status
                $.ajax({
                    url: '{{ route('update.product.status') }}',
                    type: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        product_id: productId,
                        popular: isChecked ? 1 : 0
                    },
                    success: function(response) {
                        // Handle success response if needed
                        if (response.success) {
                            // Display success alert
                            var alert = $(
                                '<div class="alert alert-success" role="alert">Product status updated successfully</div>'
                            );
                            $('#alertContainer').empty().append(alert);

                            // Automatically hide the alert after a few seconds
                            setTimeout(function() {
                                alert.fadeOut('slow');
                            }, 3000);
                        } else {
                            console.error('Failed to update product status');
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error(xhr.responseText);
                    }
                });
            });
        });
    </script>
@endpush
