@extends('admin.master')

@section('admin-home-section')
    <div class="container-fluid pt-4 px-4">
        <div class="row g-4">
            <h2>Sub Category</h2>
            <div class="col-sm-12 col-xl-12">
                <div class="bg-light rounded h-100 p-4">
                    <h6 class="mb-4">{{ isset($sub_category) ? 'Edit' : 'Add' }} Sub Category</h6>

                    @error('error')
                        {{ $message }}
                    @enderror
                    <form method="POST" enctype="multipart/form-data"
                        action="{{ isset($sub_category) ? route('sub_category.update', ['id' => $sub_category->id]) : route('sub_category.store') }}">
                        @csrf
                        @if (isset($sub_category))
                            @method('PATCH')
                        @endif
                        <div class="row mb-3">
                            <div class="col">
                                <label for="ctg_id" class="form-label">Category Name</label>
                                <select class="selectpicker p-0 w-100 form-select @error('ctg_id') is-invalid @enderror"
                                    id="ctg_id" name="ctg_id" data-show-subtext="true" data-live-search="true">
                                    <option value="" disabled selected>Select Category</option>
                                    @foreach ($categories as $category)
                                        <option value="{{ $category->id }}"
                                            {{ old('ctg_id') == $category->id || (isset($sub_category) && $sub_category->category->id == $category->id) ? 'selected' : '' }}>
                                            {{ $category->ctg_name }}
                                        </option>
                                    @endforeach

                                </select>
                                @error('ctg_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                            <div class="col">
                                <label for="sub_ctg_name" class="form-label">Sub Category Name</label>
                                <input type="text" class="form-control @error('sub_ctg_name') is-invalid @enderror"
                                    id="sub_ctg_name" name="sub_ctg_name"
                                    value="{{ isset($sub_category) ? $sub_category->sub_ctg_name : '' }}">
                                @error('sub_ctg_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                <label for="slug" class="form-label">Slug</label>
                                <input type="text" class="form-control @error('slug') is-invalid @enderror"
                                    id="slug" name="slug"
                                    value="{{ isset($sub_category) ? $sub_category->slug : '' }}">
                                @error('slug')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                        </div>
                        <div class="row mb-3">

                            <div class="col">
                                <label for="alt_tag" class="form-label">Meta keywords</label>
                                <input type="text" class="form-control p-0 bg-white" id="alt_tag" name="alt_tag"
                                    value="{{ isset($sub_category)? implode(', ',collect(json_decode($sub_category->alt_tag))->pluck('value')->toArray()): '' }}">
                            </div>
                            <div class="col">
                                <label for="meta_title" class="form-label">Meta Title</label>
                                <input type="text" class="form-control @error('meta_title') is-invalid @enderror"
                                    id="meta_title" name="meta_title"
                                    value="{{ isset($sub_category) ? $sub_category->meta_title : '' }}">
                                @error('meta_title')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                <label for="meta_description" class="form-label">Meta Description</label>
                                <textarea class="form-control @error('meta_description') is-invalid @enderror" id="meta_description"
                                    name="meta_description">{{ isset($sub_category) ? $sub_category->meta_description : '' }}</textarea>
                                @error('meta_description')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row mb-3">
                            <div class="col">
                                @if (isset($sub_category))
                                    <label for="sub_ctg_banner" class="form-label">Current Banner</label>
                                    <br> <img
                                        src="{{ asset('uploads/sub_category/banner/' . $sub_category->sub_ctg_banner) }}"
                                        alt="sub_Category Banner" class="banner-style mb-2"
                                        style="max-width: 200px; max-height: 200px;">
                                    <br> <span>Update For New</span>
                                @endif
                                <label for="sub_ctg_banner" class="form-label">Banner</label>
                                <input type="file" class="form-control @error('sub_ctg_banner') is-invalid @enderror"
                                    id="sub_ctg_banner" name="sub_ctg_banner">
                                <small id="helpId" class="text-secondary">The banner image dimensions must be at least
                                    1920x745 pixels*</small>
                                @error('sub_ctg_banner')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                            <div class="col">
                                @if (isset($sub_category))
                                    <label for="sub_ctg_main_img" class="form-label">Current Main Image</label>
                                    <br> <img
                                        src="{{ asset('uploads/sub_category/main/' . $sub_category->sub_ctg_main_img) }}"
                                        alt="sub_Category main_img" class="banner-style mb-2"
                                        style="max-width: 200px; max-height: 200px;">
                                    <br> <span>Update For New</span>
                                @endif
                                <label for="sub_ctg_main_img" class="form-label">Main Image</label>
                                <input type="file" class="form-control @error('sub_ctg_main_img') is-invalid @enderror"
                                    id="sub_ctg_main_img" name="sub_ctg_main_img">
                                <small id="helpId" class="text-secondary">The main image dimensions must be at least
                                    200x176  pixels.</small>
                                @error('sub_ctg_main_img')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>


                        <button type="submit" class="btn btn-success mt-3">{!! isset($sub_category) ? '<i class="fa fa-save"></i>  Update' : '<i class="fa fa-plus"></i> Add' !!}</button>
                        <a class="btn btn-danger ms-md-4 mt-3" onclick="location.href='{{ route('sub_category') }}'"><i
                                class="fa fa-arrow-left"></i> Back</a>
                    </form>

                </div>
            </div>
        </div>
    </div>
@endsection
@push('style')
<style>
        .banner-style {
            aspect-ratio: 16 / 9;
            width: 300px;
            object-fit: cover;
            object-position: center right;
        }
        .btn-light{
            background:white !important;
        }
    </style>
@endpush
