@extends('frontend.layouts.master')
@section('main-section')
    <main>
        <section>
            <div class="pt-5 mx-auto container-lg py-md-5">
                <div class="px-2 d-flex justify-content-between align-items-center px-lg-0">
                    <div class="gap-0 d-flex align-items-center">
                        <a href="index.html" class="text-black fw-medium text-decoration-none fs-6">Home</a>
                        <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none"
                            stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"
                            class="lucide lucide-chevron-right">
                            <path d="m9 18 6-6-6-6" />
                        </svg>
                        <p style="cursor: default" class="text-black fw-medium fs-6">
                            Shop Page
                        </p>
                    </div>
                    {{-- <div class="dropdown-center">
                        <button style="background: #f9f2e8; border: 1px solid #b8b8b8"
                            class="text-black btn dropdown-toggle fw-normal" type="button" data-bs-toggle="dropdown"
                            aria-expanded="false">
                            Default Sorting
                        </button>
                        <ul class="dropdown-menu">
                            <li><a class="dropdown-item" href="#">Action</a></li>
                            <li><a class="dropdown-item" href="#">Action two</a></li>
                            <li><a class="dropdown-item" href="#">Action three</a></li>
                        </ul>
                    </div> --}}
                </div>

                <div class="row-gap-4 my-5 row px-md-3 px-lg-0">
                    <div class="col-md-4 col-lg-3 p-md-0">
                        <div style="top: 3%" class="sticky-md-top">
                            <p class="text-black fw-medium">Search your tiles</p>
                            <form id="searchForm" method="get" action="{{ route('search') }}"
                                style="border: 1px solid #d5d4d4"
                                class="gap-2 py-1 mt-2 bg-white d-flex align-items-center rounded-2 ps-1 pe-2">
                                @csrf
                                <input type="text" id="searchInput" name="query"
                                    class="bg-transparent border-0 form-control" placeholder="Search Products" required>
                                <button type="submit" class="bg-transparent border-0">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24"
                                        viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2"
                                        stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-search">
                                        <circle cx="11" cy="11" r="8" />
                                        <path d="m21 21-4.3-4.3" />
                                    </svg>
                                </button>
                            </form>
                            <form id="categoryFilter">
                                <div class="mt-5">
                                    <p class="text-black fw-medium fs-5">Shop by categories</p>
                                    <ul class="mt-3 ps-0 list-unstyled">
                                        @foreach ($categories as $category)
                                            <li>
                                                <div class="form-check">
                                                    <input class="form-check-input category-input" type="radio"
                                                        name="category_id" value="{{ $category->id }}"
                                                        id="category_{{ $category->id }}">
                                                    <label class="form-check-label fw-medium"
                                                        for="category_{{ $category->id }}">
                                                        {{ $category->ctg_name }}
                                                    </label>
                                                </div>
                                            </li>
                                        @endforeach

                                    </ul>
                                </div>
                            </form>

                        </div>
                    </div>
                    <div class="px-0 col-md-8 col-lg-9 ps-md-5 pe-md-0">
                        <div class="row-gap-5 row row-gap-md-5" id="product-container">
                            @foreach ($products as $product)
                                <div class="p-0 col-md-6 col-lg-4">
                                    <a href="{{ route('productDetails', ['slug' => $product->slug]) }}"
                                        class="text-decoration-none d-inline-block tiles_card">
                                        <img src="{{ asset(config('paths.product') . $product->product_main_img) }}"
                                            alt="{{ $product->alt_tag }}" />
                                        <p class="mt-2 text-black fs-6 fw-medium">
                                            {{ $product->product_name }}
                                        </p>
                                    </a>
                                </div>
                            @endforeach

                        </div>
                        <div class="mt-5 d-flex justify-content-center align-items-center">
                            <nav aria-label="Page navigation example">
                                <!-- Pagination Links -->
                                @if ($products->lastPage() > 1)
                                    <ul class="pagination">
                                        <li class="page-item {{ $products->onFirstPage() ? ' disabled' : '' }}">
                                            <a class="page-link" href="{{ $products->previousPageUrl() }}"
                                                aria-disabled="{{ $products->onFirstPage() ? 'true' : 'false' }}">Previous</a>
                                        </li>
                                        @for ($i = 1; $i <= $products->lastPage(); $i++)
                                            <li class="page-item {{ $products->currentPage() == $i ? ' active' : '' }}">
                                                <a class="page-link"
                                                    href="{{ $products->url($i) }}">{{ $i }}</a>
                                            </li>
                                        @endfor
                                        <li class="page-item {{ $products->hasMorePages() ? '' : ' disabled' }}">
                                            <a class="page-link" href="{{ $products->nextPageUrl() }}">Next</a>
                                        </li>
                                    </ul>
                                @endif
                            </nav>
                        </div>

                    </div>
                </div>
            </div>
        </section>
    </main>
@endsection
@push('script')
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Select all category inputs
            const categoryInputs = document.querySelectorAll('.category-input');
            console.log('Category Inputs:', categoryInputs);

            if (categoryInputs.length === 0) {
                console.error('No category inputs found!');
                return;
            }

            // Attach event listeners to each category input
            categoryInputs.forEach(input => {
                input.addEventListener('change', function() {
                    console.log('Selected Category ID:', this.value);
                    if (this.value) {
                        fetchProductsByCategory(this.value);
                    } else {
                        console.error('Undefined category ID');
                    }
                });
            });

            // Function to fetch products by category ID
            function fetchProductsByCategory(categoryId) {
                if (!categoryId) {
                    console.error('Category ID is undefined. Cannot fetch products.');
                    return;
                }

                const url = `/fetch-products?category_id=${categoryId}`;
                console.log('Fetching products from URL:', url);

                fetch(url)
                    .then(response => {
                        if (!response.ok) {
                            throw new Error('Network response was not ok');
                        }
                        return response.json();
                    })
                    .then(data => {
                        displayProducts(data.products);
                    })
                    .catch(error => console.error('Error fetching data:', error));
            }

            // Function to display products in the product container
            function displayProducts(products) {
                const productContainer = document.getElementById('product-container');
                if (!productContainer) {
                    console.error('Product container not found!');
                    return;
                }

                productContainer.innerHTML = ''; // Clear existing products
                var productImagePath = "{{ config('paths.product') }}";
                products.forEach(product => {
                    const productElement = document.createElement('div');
                    productElement.className = 'p-0 col-md-6 col-lg-4';
                    productElement.innerHTML = `
                <a href="/product-details/${product.slug}" class="text-decoration-none d-inline-block tiles_card">
                    <img src="${productImagePath + product.product_main_img}" alt="${product.alt_tag}" />
                    <p class="mt-2 text-black fs-6 fw-medium">${product.product_name}</p>
                </a>
            `;
                    productContainer.appendChild(productElement);
                });
            }
        });
    </script>
@endpush
