<?php

use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\SubCategoryController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\SiteSettingController;
use App\Http\Controllers\FrontendController;

// =========== frontend ===============
Route::get('/', [FrontendController::class, 'home'])->name('home');
Route::get('about-us', [FrontendController::class, 'about'])->name('about');
Route::get('contact-us', [FrontendController::class, 'contact'])->name('contact');
Route::get('products', [FrontendController::class, 'products'])->name('products');
Route::get('product-details/{slug}', [FrontendController::class, 'productDetails'])->name('productDetails');
Route::get('/search-products', [FrontendController::class, 'searchProducts']);
Route::get('/cate/{id}/subcategories', 'FrontendController@getSubCategories');
Route::get('/fetch-products', 'App\Http\Controllers\FrontendController@fetchProductsByCategory');
//============== Search product ===================
Route::any('/search', [FrontendController::class, 'search'])->name('search');
Route::any('/search/suggest', [FrontendController::class, 'searchSuggest'])->name('search.suggest');
//============== User category ===================
Route::get('/subcategory-details/{slug}', [FrontendController::class, 'subcategoryDetail'])->name('subcategoryDetail');
Route::get('cate/{category}', [FrontendController::class, 'frontendCategory'])
    ->name('category.subcategories');
Route::get('/fetch-subcategories', [FrontendController::class, 'fetchByCategory'])->name('fetch.subcategories');

// =========== end  frontend===============

// =========== Admin ===============
Route::middleware(['auth', 'verified'])->group(function () {
    Route::get('/dashboard', function () {
        return view('dashboard');
    })->name('dashboard');
    // =========== site images  ===============
    Route::get('site-images', [SiteSettingController::class, 'getSiteImages'])->name('site-images');
    Route::post('site-images/update', [SiteSettingController::class, 'updateSiteImages'])->name('site-images.update');
    Route::get('dashboard', [SiteSettingController::class, 'dashboard'])->name('dashboard');

    // =========== category ===============
    Route::get('category', [CategoryController::class, 'index'])->name('category');
    Route::get('category/manage', [CategoryController::class, 'create'])->name('category.create');
    Route::post('category/manage/store', [CategoryController::class, 'store'])->name('category.store');
    Route::get('category/manage/edit/{id}', [CategoryController::class, 'show'])->name('category.edit');
    Route::patch('category/manage/update/{id}', [CategoryController::class, 'update'])->name('category.update');
    Route::delete('category/delete/{id}', [CategoryController::class, 'destroy'])->name('category.delete');
    Route::get('category/view/{id}', [CategoryController::class, 'viewCtg'])->name('category.view');

    // =========== sub category ===============
    Route::get('sub-category', [SubCategoryController::class, 'index'])->name('sub_category');
    Route::get('sub-category/manage', [SubCategoryController::class, 'create'])->name('sub_category.create');
    Route::post('sub-category/manage/store', [SubCategoryController::class, 'store'])->name('sub_category.store');
    Route::get('sub-category/manage/edit/{id}', [SubCategoryController::class, 'show'])->name('sub_category.edit');
    Route::patch('sub-category/manage/update/{id}', [SubCategoryController::class, 'update'])->name('sub_category.update');
    Route::delete('sub-category/delete/{id}', [SubCategoryController::class, 'destroy'])->name('sub_category.delete');
    Route::get('sub-category/view/{id}', [SubCategoryController::class, 'viewSubCtg'])->name('sub_category.view');

    // =========== product ===============

    Route::get('product', [ProductController::class, 'index'])->name('product');
    Route::get('product/manage/add-product/', [ProductController::class, 'create'])->name('product.create');
    Route::post('product/manage/store', [ProductController::class, 'store'])->name('products.store');
    Route::get('product/manage/edit/{id}', [ProductController::class, 'show'])->name('product.edit');
    Route::patch('product/manage/update/{id}', [ProductController::class, 'update'])->name('product.update');
    Route::delete('product/delete/{id}', [ProductController::class, 'destroy'])->name('product.delete');
    Route::post('/update-product-status', [ProductController::class, 'updateStatus'])->name('update.product.status');
    Route::get('/get-subcategories', [ProductController::class, 'getSubcategories'])->name('getSubcategories');
    Route::get('product/view/{id}', [ProductController::class, 'viewProduct'])->name('product.view');

    // =========== Whatsapp ===============
    Route::get('whatsapp', [SiteSettingController::class, 'whatsappIndex'])->name('whatsapp');
    Route::get('whatsapp/manage', [SiteSettingController::class, 'whatsappCreate'])->name('whatsapp.create');
    Route::post('whatsapp/manage/store', [SiteSettingController::class, 'whatsappStore'])->name('whatsapp_configs.store');
    Route::get('whatsapp/manage/edit/{id}', [SiteSettingController::class, 'whatsappShow'])->name('whatsapp.edit');
    Route::patch('whatsapp/manage/update/{id}', [SiteSettingController::class, 'whatsappUpdate'])->name('whatsapp.update');
    Route::delete('whatsapp/delete/{id}', [SiteSettingController::class, 'whatsappDelete'])->name('whatsapp.delete');
    Route::get('whatsapp/view/{id}', [SiteSettingController::class, 'viewWhatsapp'])->name('whatsapp.view');

    // =========== main menu  ===============
    Route::get('main-menu', [SiteSettingController::class, 'getMenu'])->name('main-menu');
    Route::post('main-menu/update-category-status', [SiteSettingController::class, 'updateCategoryStatus'])->name('update.category.status');
});
Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});

require __DIR__ . '/auth.php';
